from .base import BaseCFObject


class Parameter(BaseCFObject):
    top_level_key = "Parameters"
